@@ -25,38 +25,34 @@ class UpdateTableModelInfoRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'UpdateTableModelInfo')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SecondLevelThemeId(self):
+	def get_SecondLevelThemeId(self): # Long
 		return self.get_query_params().get('SecondLevelThemeId')
 
-	def set_SecondLevelThemeId(self,SecondLevelThemeId):
-		self.add_query_param('SecondLevelThemeId',SecondLevelThemeId)
-
-	def get_TableGuid(self):
+	def set_SecondLevelThemeId(self, SecondLevelThemeId):  # Long
+		self.add_query_param('SecondLevelThemeId', SecondLevelThemeId)
+	def get_TableGuid(self): # String
 		return self.get_query_params().get('TableGuid')
 
-	def set_TableGuid(self,TableGuid):
-		self.add_query_param('TableGuid',TableGuid)
-
-	def get_LevelId(self):
+	def set_TableGuid(self, TableGuid):  # String
+		self.add_query_param('TableGuid', TableGuid)
+	def get_LevelId(self): # Long
 		return self.get_query_params().get('LevelId')
 
-	def set_LevelId(self,LevelId):
-		self.add_query_param('LevelId',LevelId)
-
-	def get_LevelType(self):
+	def set_LevelId(self, LevelId):  # Long
+		self.add_query_param('LevelId', LevelId)
+	def get_LevelType(self): # Integer
 		return self.get_query_params().get('LevelType')
 
-	def set_LevelType(self,LevelType):
-		self.add_query_param('LevelType',LevelType)
-
-	def get_FirstLevelThemeId(self):
+	def set_LevelType(self, LevelType):  # Integer
+		self.add_query_param('LevelType', LevelType)
+	def get_FirstLevelThemeId(self): # Long
 		return self.get_query_params().get('FirstLevelThemeId')
 
-	def set_FirstLevelThemeId(self,FirstLevelThemeId):
-		self.add_query_param('FirstLevelThemeId',FirstLevelThemeId)
\ No newline at end of file
+	def set_FirstLevelThemeId(self, FirstLevelThemeId):  # Long
+		self.add_query_param('FirstLevelThemeId', FirstLevelThemeId)
